
Linux
=====

 0. The standard build utilities  (gcc, g++, gfortran)

 1. Anconda3 version 2.5.0 or newer (Python version 3.5 or newer) from https://www.continuum.io/downloads

 2. The anaconda packages listed in the `requirements.txt` file.

 3. Our repository from gitlab.


MacOS
=====

 0. The standard build utilities (llvm or gcc, g++, gfortran)

 1. Anconda3 version 2.5.0 or newer (Python version 3.5 or newer) from https://www.continuum.io/downloads

 2. The anaconda packages listed in the `requirements.txt` file.

 3. Our repository from gitlab.

Windows
=======

 0. Microsoft Visual Studio 2015 (version 14.0), including the Visual C++ language pack and the Windows Development Kit options.  Due to the limitations of earlier versions of Visual Studio, other versions will not work!

 1. Anconda3 version 2.5.0 or newer (Python version 3.5 or newer) from https://www.continuum.io/downloads

 2. The anaconda packages listed in the `requirements.txt` file.

 3. Our repository from gitlab.

